#include <stdlib.h>
#include "NxPhysics.h"

int main(int argc, char* argv[])
{
	NxPhysicsSDK* physicsSDK = NxCreatePhysicsSDK(NX_PHYSICS_SDK_VERSION, NULL);
	physicsSDK->getFoundationSDK().getRemoteDebugger()->connect("localhost", 5425);
	NxSceneDesc sceneDesc;
	sceneDesc.gravity = NxVec3(0.0f, -10.0f, 0.0f);
	NxScene* scene = physicsSDK->createScene(sceneDesc);

	NxMaterial* defaultMaterial = scene->getMaterialFromIndex(0);
	defaultMaterial->setRestitution(0.6f);
	defaultMaterial->setStaticFriction(0.4f);
	defaultMaterial->setDynamicFriction(0.2f);

	for(int i = 0; i < 1000; i++)
	{
		NxSphereShapeDesc sphereDesc;
		sphereDesc.radius = 0.5f;
		NxActorDesc sphereActorDesc;
		sphereActorDesc.shapes.pushBack(&sphereDesc);
		NxBodyDesc bodyDesc;
		sphereActorDesc.body = &bodyDesc;
		sphereActorDesc.density = 1.0;
		sphereActorDesc.globalPose.t = NxVec3(1.2f*((i%100)%10), 5.0f + i/100*1.2f, 1.2f*((i%100)/10));
		NxActor* s = scene->createActor(sphereActorDesc);
		s->setLinearVelocity( NxVec3(0.5f*sin((float)i), 0.5f*sin(10.0f*i),0.5f*sin(30.0f*i)));
	}

	NxActor* c = NULL;
	{
		NxBoxShapeDesc boxDesc;
		boxDesc.dimensions = NxVec3(5.0f, 5.0f, 5.0f);
		NxActorDesc boxActorDesc;
		boxActorDesc.shapes.pushBack(&boxDesc);
		NxBodyDesc bodyDesc;
		boxActorDesc.body = &bodyDesc;
		boxActorDesc.density = 1.0;
		NxMat34 m1;
		m1.id();
		NxMat33 m;
		m.rotX(45.0f);
		NxVec3 v = NxVec3(-70.0f, 7.0f, 0.0f);
		NxMat34 m2(m, v);
		boxActorDesc.globalPose.multiply(m1, m2);
		c = scene->createActor(boxActorDesc);
		c->raiseBodyFlag(NX_BF_KINEMATIC);
	}

	{
		NxPlaneShapeDesc planeDesc;
		planeDesc.normal = NxVec3(0.0f, 1.0f, 0.0f);
		NxActorDesc planeActorDesc;
		planeActorDesc.shapes.pushBack(&planeDesc);
		planeActorDesc.globalPose.t = NxVec3(0.0f, 0.0f, 0.0f);
		NxActor* p = scene->createActor(planeActorDesc);
	}

	for(int i = 0; i < 1000; i++)
	{
		scene->simulate(0.1f);
		scene->flushStream();
		scene->fetchResults(NX_RIGID_BODY_FINISHED, true);

		c->moveGlobalPosition(NxVec3(10.0f*sin(0.3f*i), 7.0f, 0.0f));
	}

	physicsSDK->getFoundationSDK().getRemoteDebugger()->disconnect();
	return 0;
}